==> muse_2.1.2.orig.tar.xz: muse-2.1.2/awl/midipanentry.h <==
//=============================================================================
//  Awl
//  Audio Widget Library
//  $Id:$
//
//  Copyright (C) 1999-2011 by Werner Schweer and others
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; version 2 of
//  the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//=============================================================================

#ifndef __AWLMIDIPANENTRY_H__
#define __AWLMIDIPANENTRY_H__

#include "floatentry.h"

namespace Awl {

//---------------------------------------------------------
//   MidiPanEntry
//---------------------------------------------------------

class MidiPanEntry : public FloatEntry {
      Q_OBJECT

   protected:
      virtual void valueChange();

   public slots:
      virtual void setValue(double v) {
            FloatEntry::setValue(v - 64.0f);
            }
   public:
      MidiPanEntry(QWidget* parent);
      virtual double value() const  { return _value + 64.0f; }
      };
}

#endif

==> muse_3.0.2.1+rb2.orig.tar.xz: muse-3.0.2.1+rb2/awl/midipanentry.h <==
//=============================================================================
//  Awl
//  Audio Widget Library
//  $Id:$
//
//  Copyright (C) 1999-2011 by Werner Schweer and others
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; version 2 of
//  the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//=============================================================================

#ifndef __AWLMIDIPANENTRY_H__
#define __AWLMIDIPANENTRY_H__

#include "floatentry.h"

namespace Awl {

//---------------------------------------------------------
//   MidiPanEntry
//---------------------------------------------------------

class MidiPanEntry : public FloatEntry {
      Q_OBJECT

      bool _leftMouseButtonCanDecrease;
      
   protected:
      virtual void valueChange();

   public slots:
      virtual void setValue(double v) {
            FloatEntry::setValue(v - 64.0f);
            }
   public:
      MidiPanEntry(QWidget* parent, bool leftMouseButtonCanDecrease = false);
      virtual double value() const  { return _value + 64.0f; }
      
      bool leftMouseButtonCanDecrease() const { return _leftMouseButtonCanDecrease; }
      void setLeftMouseButtonCanDecrease(bool v) { _leftMouseButtonCanDecrease = v; }
      };
}

#endif
